@@ -30,13 +30,17 @@
   (:use #:common-lisp)
   (:export stumpwm))
      
-(require :cmucl-clx)
+;(require :clx)
 
 (in-package #:stumpwm)
 
 
 ;;; Hooks
 
+(defun char->keysym (ch)
+  "Convert a char to a keysym"
+  (first (xlib:character->keysyms ch)))
+
 (defvar *map-window-hook* '()
   "A hook called whenever a window is mapped.")
 
@@ -63,7 +67,7 @@
 (defvar *font-name* "9x15bold"
   "The name of the font to use when stumpwm displays messages.")
 
-(defvar *prefix-key* (xlib:keysym #\t)
+(defvar *prefix-key* (char->keysym #\t)
   "The key to use as the prefix key")
 
 (defvar *prefix-modifiers* '(:control)
@@ -90,25 +94,25 @@ screen and window. It should return a string.")
   (fn nil :type function))
 
 (defparameter *key-binding-alist*
-  (list (cons (xlib:keysym #\n) 'focus-next-window)
-	(cons (xlib:keysym #\p) 'focus-prev-window)
-	(cons (xlib:keysym #\w) 'echo-windows)
-	(cons (xlib:keysym #\k) 'delete-current-window)
-	(cons (xlib:keysym #\b) 'banish-pointer)
-	(cons (xlib:keysym #\') 'select-window)
-	(cons (xlib:keysym #\t) 'other-window)
-	(cons (xlib:keysym #\g) (lambda (s))) ; abort
-	(cons (xlib:keysym #\0) (lambda (s) (select-window-number s 0)))
-	(cons (xlib:keysym #\1) (lambda (s) (select-window-number s 1)))
-	(cons (xlib:keysym #\2) (lambda (s) (select-window-number s 2)))
-	(cons (xlib:keysym #\3) (lambda (s) (select-window-number s 3)))
-	(cons (xlib:keysym #\4) (lambda (s) (select-window-number s 4)))
-	(cons (xlib:keysym #\5) (lambda (s) (select-window-number s 5)))
-	(cons (xlib:keysym #\6) (lambda (s) (select-window-number s 6)))
-	(cons (xlib:keysym #\7) (lambda (s) (select-window-number s 7)))
-	(cons (xlib:keysym #\8) (lambda (s) (select-window-number s 8)))
-	(cons (xlib:keysym #\9) (lambda (s) (select-window-number s 9))))
-		"An alist of keysym function pairs.")
+  (list (cons (char->keysym #\n) 'focus-next-window)
+	(cons (char->keysym #\p) 'focus-prev-window)
+	(cons (char->keysym #\w) 'echo-windows)
+	(cons (char->keysym #\k) 'delete-current-window)
+	(cons (char->keysym #\b) 'banish-pointer)
+	(cons (char->keysym #\') 'select-window)
+	(cons (char->keysym #\t) 'other-window)
+	(cons (char->keysym #\g) (lambda (s))) ; abort
+	(cons (char->keysym #\0) (lambda (s) (select-window-number s 0)))
+	(cons (char->keysym #\1) (lambda (s) (select-window-number s 1)))
+	(cons (char->keysym #\2) (lambda (s) (select-window-number s 2)))
+	(cons (char->keysym #\3) (lambda (s) (select-window-number s 3)))
+	(cons (char->keysym #\4) (lambda (s) (select-window-number s 4)))
+	(cons (char->keysym #\5) (lambda (s) (select-window-number s 5)))
+	(cons (char->keysym #\6) (lambda (s) (select-window-number s 6)))
+	(cons (char->keysym #\7) (lambda (s) (select-window-number s 7)))
+	(cons (char->keysym #\8) (lambda (s) (select-window-number s 8)))
+	(cons (char->keysym #\9) (lambda (s) (select-window-number s 9))))
+  "An alist of keysym function pairs.")
 
 ;; FIXME: This variable is set only once but it needs to be set after
 ;; the display is opened. So should it have +'s around it even though
@@ -544,21 +548,21 @@ than the root window's width and height."
 
 (defun is-modifier (keysym)
   "Return t if keycode is a modifier"
-  (member keysym (list (xlib:keysym :character-set-switch)
-		       (xlib:keysym :left-shift)
-		       (xlib:keysym :right-shift)
-		       (xlib:keysym :left-control)
-		       (xlib:keysym :right-control)
-		       (xlib:keysym :caps-lock)
-		       (xlib:keysym :shift-lock)
-		       (xlib:keysym :left-meta)
-		       (xlib:keysym :right-meta)
-		       (xlib:keysym :left-alt)
-		       (xlib:keysym :right-alt)
-		       (xlib:keysym :left-super)
-		       (xlib:keysym :right-super)
-		       (xlib:keysym :left-hyper)
-		       (xlib:keysym :right-hyper))))
+  (member keysym (list (char->keysym :character-set-switch)
+		       (char->keysym :left-shift)
+		       (char->keysym :right-shift)
+		       (char->keysym :left-control)
+		       (char->keysym :right-control)
+		       (char->keysym :caps-lock)
+		       (char->keysym :shift-lock)
+		       (char->keysym :left-meta)
+		       (char->keysym :right-meta)
+		       (char->keysym :left-alt)
+		       (char->keysym :right-alt)
+		       (char->keysym :left-super)
+		       (char->keysym :right-super)
+		       (char->keysym :left-hyper)
+		       (char->keysym :right-hyper))))
 
 (defun handle-command-key (screen code state)
   "Find the command mapped to the (code state) and executed it."
